==> apache-flume-1.5.0.1-src.tar.gz: apache-flume-1.5.0.1-src/flume-ng-tests/src/test/java/org/apache/flume/test/agent/TestRpcClient.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.flume.test.agent;

import org.apache.flume.api.RpcClient;
import org.apache.flume.api.RpcClientFactory;
import org.apache.flume.event.EventBuilder;
import org.apache.flume.test.util.StagedInstall;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;

public class TestRpcClient {

  public static final String CONFIG_FILE_PRCCLIENT_TEST =
      "rpc-client-test.properties";

  @Before
  public void setUp() throws Exception {
    StagedInstall.getInstance().startAgent(
        "rpccagent", CONFIG_FILE_PRCCLIENT_TEST);
  }

  @After
  public void tearDown() throws Exception {
    StagedInstall.getInstance().stopAgent();
  }

  @Test
  public void testRpcClient() throws Exception {
    StagedInstall.waitUntilPortOpens("localhost", 12121, 20000);
    RpcClient client = RpcClientFactory.getDefaultInstance("localhost", 12121);
    String[] text = {"foo", "bar", "xyz", "abc"};
    for (String str : text) {
      client.append(EventBuilder.withBody(str.getBytes()));
    }
  }

}

==> apache-flume-1.9.0-src.tar.gz: apache-flume-1.9.0-src/flume-ng-tests/src/test/java/org/apache/flume/test/agent/TestRpcClient.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.flume.test.agent;

import org.apache.flume.api.RpcClient;
import org.apache.flume.api.RpcClientFactory;
import org.apache.flume.event.EventBuilder;
import org.apache.flume.test.util.StagedInstall;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;

public class TestRpcClient {

  public static final String CONFIG_FILE_PRCCLIENT_TEST =
      "rpc-client-test.properties";
  private int port;

  @Before
  public void setUp() throws Exception {
    port = StagedInstall.getInstance().startAgent(
        "rpccagent", CONFIG_FILE_PRCCLIENT_TEST);
  }

  @After
  public void tearDown() throws Exception {
    StagedInstall.getInstance().stopAgent();
  }

  @Test
  public void testRpcClient() throws Exception {
    StagedInstall.waitUntilPortOpens("localhost", port, 20000);
    RpcClient client = RpcClientFactory.getDefaultInstance("localhost", port);
    String[] text = {"foo", "bar", "xyz", "abc"};
    for (String str : text) {
      client.append(EventBuilder.withBody(str.getBytes()));
    }
  }

}
